/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JContainerConfig.java 572 2006-06-04 21:23:27Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.container;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.api.EZBContainerConfig;
import org.objectweb.easybeans.api.EZBContainerLifeCycleCallback;
import org.objectweb.easybeans.api.EZBServer;
import org.objectweb.easybeans.api.injection.ResourceInjector;

/**
 * Store Configuration for a {@link JContainer3} instance.
 * @author Guillaume Sauthier
 */
public class JContainerConfig implements EZBContainerConfig {

    /**
     * EjbJar archive.
     */
    private File archive;

    /**
     * Embedded server.
     */
    private EZBServer embedded;

    /**
     * Callback List.
     */
    private List<EZBContainerLifeCycleCallback> callbacks;

    /**
     * Resource Injectors List.
     */
    private List<ResourceInjector> injectors;

    /**
     * Constructor.
     * @param archive the archive to process.
     */
    public JContainerConfig(final File archive) {
        super();
        this.archive = archive;
        this.callbacks = new ArrayList<EZBContainerLifeCycleCallback>();
        this.injectors = new ArrayList<ResourceInjector>();
    }

    /**
     * @return the callbacks
     */
    public List<EZBContainerLifeCycleCallback> getCallbacks() {
        return callbacks;
    }

    /**
     * @param callback the callbacks to add.
     */
    public void addCallback(final EZBContainerLifeCycleCallback callback) {
        this.callbacks.add(callback);
    }

    /**
     * @return the archive
     */
    public File getArchive() {
        return archive;
    }

    /**
     * @return the injectors
     */
    public List<ResourceInjector> getInjectors() {
        return injectors;
    }

    /**
     * @param injector the injectors to set
     */
    public void addInjectors(final ResourceInjector injector) {
        this.injectors.add(injector);
    }

    /**
     * @return the embedded server
     */
    public EZBServer getEZBServer() {
        return embedded;
    }

    /**
     * Sets the embedded server.
     * @param embedded the embedded server of this config
     */
    public void setEZBServer(final EZBServer embedded) {
        this.embedded = embedded;
    }
}
